# FeatureFlag

Controls an Agilicus feature's settings

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**feature** | **str** | The name of the feature | 
**enabled** | **bool** | Whether the feature is enabled | 
**setting** | **str** | a specific setting for the feature | [optional]  if omitted the server will use the default value of ""
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


